@@ -1,7 +1,7 @@
 package Data::Dmp;
 
 our $DATE = '2016-04-30'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -89,9 +89,10 @@ sub _dump {
         if (!defined($val)) {
             return "undef";
         } elsif (looks_like_number($val) &&
-                     # strings like "0123" looks_like_number but must actually
-                     # be quoted to avoid being interpreted as an octal literal
-                     $val !~ /\A0[0-9]+\z/
+                     # perl does several normalizations to number literal, e.g.
+                     # "+1" becomes 1, 0123 is octal literal, etc. make sure we
+                     # only leave out quote when the number is not normalized
+                     $val eq $val+0
                  ) {
             return $val;
         } else {
@@ -197,7 +198,7 @@ Data::Dmp - Dump Perl data structures as Perl code
 
 =head1 VERSION
 
-This document describes version 0.17 of Data::Dmp (from Perl distribution Data-Dmp), released on 2016-04-30.
+This document describes version 0.18 of Data::Dmp (from Perl distribution Data-Dmp), released on 2016-04-30.
 
 =head1 SYNOPSIS
 
@@ -258,22 +259,22 @@ Note that without the pragmas, the dump might be incorrect.
 =head1 BENCHMARKS
 
  [1..10]:
-                       Rate    Data::Dump Data::Dumper Data::Dmp
- Data::Dump     28422+-43/s            --       -67.6%    -76.6%
- Data::Dumper  87730+-200/s 208.67+-0.85%           --    -27.6%
- Data::Dmp    121210+-170/s 326.46+-0.88% 38.16+-0.37%        --
+                      Rate    Data::Dump Data::Dumper Data::Dmp
+ Data::Dump    28085+-32/s            --       -68.2%    -76.6%
+ Data::Dumper 88260+-100/s 214.26+-0.51%           --    -26.3%
+ Data::Dmp    119782+-41/s   326.5+-0.5% 35.72+-0.17%        --
  
  [1..100]:
-                           Rate    Data::Dump   Data::Dmp Data::Dumper
- Data::Dump         3389+-5.5/s            --      -77.0%       -77.9%
- Data::Dmp    14730.5+-0.0071/s 334.65+-0.71%          --        -3.8%
- Data::Dumper       15317+-75/s     352+-2.3% 3.98+-0.51%           --
+                        Rate   Data::Dump   Data::Dmp Data::Dumper
+ Data::Dump    3390.4+-5.3/s           --      -77.0%       -77.5%
+ Data::Dmp    14734.4+-5.2/s 334.6+-0.69%          --        -2.1%
+ Data::Dumper    15047+-71/s  343.8+-2.2% 2.12+-0.48%           --
  
  Some mixed structure:
                      Rate    Data::Dump    Data::Dmp Data::Dumper
- Data::Dump    8186+-14/s            --       -70.9%       -81.0%
- Data::Dmp    28090+-46/s 243.14+-0.82%           --       -34.9%
- Data::Dumper 43158+-50/s   427.2+-1.1% 53.64+-0.31%           --
+ Data::Dump    8147+-14/s            --       -70.5%       -80.9%
+ Data::Dmp    27626+-39/s 239.09+-0.76%           --       -35.2%
+ Data::Dumper 42609+-45/s     423+-1.1% 54.23+-0.27%           --
 
 =head1 FUNCTIONS
 
